@@ -1,6 +1,4 @@
 from bgameb.game import Game
-from bgameb.players import Human, Bot
-from bgameb.stuff import Dice, Coin, Card
 from bgameb.utils import log_enable
 from bgameb._version import __version__
 
